<?php
/**
 * Theme sprecific functions and definitions
 */


/* Theme setup section
------------------------------------------------------------------- */

// Set the content width based on the theme's design and stylesheet.
if ( ! isset( $content_width ) ) $content_width = 1170; /* pixels */

// Add theme specific actions and filters
// Attention! Function were add theme specific actions and filters handlers must have priority 1
if ( !function_exists( 'ancora_theme_setup' ) ) {
	add_action( 'ancora_action_before_init_theme', 'ancora_theme_setup', 1 );
	function ancora_theme_setup() {


        // Add default posts and comments RSS feed links to head
        add_theme_support( 'automatic-feed-links' );

        // Enable support for Post Thumbnails
        add_theme_support( 'post-thumbnails' );

        // Custom header setup
        add_theme_support( 'custom-header', array('header-text'=>false));

        // Custom backgrounds setup
        add_theme_support( 'custom-background');

        // Supported posts formats
        add_theme_support( 'post-formats', array('gallery', 'video', 'audio', 'link', 'quote', 'image', 'status', 'aside', 'chat') );

        // Autogenerate title tag
        add_theme_support('title-tag');

        // Add user menu
        add_theme_support('nav-menus');

        // Add wide and full blocks support
        add_theme_support( 'align-wide' );

		// Register theme menus
		add_filter( 'ancora_filter_add_theme_menus',		'ancora_add_theme_menus' );

		// Register theme sidebars
		add_filter( 'ancora_filter_add_theme_sidebars',	'ancora_add_theme_sidebars' );

        // Set options for importer
        add_filter( 'ancora_filter_importer_options',		'ancora_set_importer_options' );

		// Set theme name and folder (for the update notifier)
		add_filter('ancora_filter_update_notifier', 		'ancora_set_theme_names_for_updater');

		// Set list of the theme required custom fonts from folder /css/font-faces
		// Attention! Font's folder must have name equal to the font's name
		ancora_set_global('required_custom_fonts', array(
			'Amadeus'
			)
		);
        global $ANCORA_GLOBALS;
        $ANCORA_GLOBALS['demo_data_url'] = esc_url(ancora_get_protocol() . '://demofiles.ancorathemes.com/dentalux/');
        $ANCORA_GLOBALS['required_plugins'] = array (
            'booked',
            'essgrids',
            'revslider',
            'trx_utils',
            'visual_composer',
            'wp_gdpr_compliance',
            'contact_form_7'
        );
	}
}


// Add page meta to the head
if (!function_exists('ancora_head_add_page_meta')) {
    add_action('wp_head', 'ancora_head_add_page_meta', 1);
    function ancora_head_add_page_meta() {
        $theme_skin = sanitize_file_name(ancora_get_custom_option('theme_skin'));
        ?>
        <meta charset="<?php bloginfo( 'charset' ); ?>" />
        <?php
        if (ancora_get_theme_option('responsive_layouts') == 'yes') {
            ?>
            <meta name="viewport" content="width=device-width, initial-scale=1, maximum-scale=1">
            <?php
        }
        if (floatval(get_bloginfo('version')) < "4.1") {
            ?>
            <title><?php wp_title( '|', true, 'right' ); ?></title>
            <?php
        }
        ?>
        <link rel="profile" href="http://gmpg.org/xfn/11" />
        <link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>" />
        <?php
        $favicon = ancora_get_custom_option('favicon');
        if (!$favicon) {
            if ( file_exists(ancora_get_file_dir('skins/'.($theme_skin).'/images/favicon.ico')) )
                $favicon = ancora_get_file_url('skins/'.($theme_skin).'/images/favicon.ico');
            if ( !$favicon && file_exists(ancora_get_file_dir('favicon.ico')) )
                $favicon = ancora_get_file_url('favicon.ico');
        }
        if ($favicon) {
            ?>
            <link rel="icon" type="image/x-icon" href="<?php echo esc_url($favicon); ?>" />
            <?php
        }

    }
}


// Add/Remove theme nav menus
if ( !function_exists( 'ancora_add_theme_menus' ) ) {
	//Handler of add_filter( 'ancora_action_add_theme_menus', 'ancora_add_theme_menus' );
	function ancora_add_theme_menus($menus) {
		
		//For example:
		//$menus['menu_footer'] = __('Footer Menu', 'dentalux');
		//if (isset($menus['menu_panel'])) unset($menus['menu_panel']);
		
		if (isset($menus['menu_side'])) unset($menus['menu_side']);
		return $menus;
	}
}


// Add theme specific widgetized areas
if ( !function_exists( 'ancora_add_theme_sidebars' ) ) {
	//Handler of add_filter( 'ancora_filter_add_theme_sidebars',	'ancora_add_theme_sidebars' );
	function ancora_add_theme_sidebars($sidebars=array()) {
		if (is_array($sidebars)) {
			$theme_sidebars = array(
				'sidebar_main'		=> __( 'Main Sidebar', 'dentalux' ),
				'sidebar_footer'	=> __( 'Footer Sidebar', 'dentalux' )
			);
			$sidebars = array_merge($theme_sidebars, $sidebars);
		}
		return $sidebars;
	}
}

// Set theme name and folder (for the update notifier)
if ( !function_exists( 'ancora_set_theme_names_for_updater' ) ) {
	//Handler of add_filter('ancora_filter_update_notifier', 'ancora_set_theme_names_for_updater');
	function ancora_set_theme_names_for_updater($opt) {
		$opt['theme_name']   = 'DENTALUX';
		$opt['theme_folder'] = 'dentalux';
		return $opt;
	}
}



//------------------------------------------------------------------------
// One-click import support
//------------------------------------------------------------------------

// Set theme specific importer options
if ( ! function_exists( 'ancora_importer_set_options' ) ) {
    add_filter( 'trx_utils_filter_importer_options', 'ancora_importer_set_options', 9 );
    function ancora_importer_set_options( $options=array() ) {
        if ( is_array( $options ) ) {
            // Save or not installer's messages to the log-file
            $options['debug'] = false;
            // Prepare demo data
            if ( is_dir( ANCORA_THEME_PATH . 'demo/' ) ) {
                $options['demo_url'] = ANCORA_THEME_PATH . 'demo/';
            } else {
                $options['demo_url'] = esc_url( ancora_get_protocol().'://demofiles.ancorathemes.com/dentalux/' ); // Demo-site domain
            }

            // Required plugins
            $options['required_plugins'] =  array(
                'booked',
                'essential-grid',
                'revslider',
                'trx_utils',
                'js_composer',
                'contact-form-7',
            );

            $options['theme_slug'] = 'ancora';

            // Set number of thumbnails to regenerate when its imported (if demo data was zipped without cropped images)
            // Set 0 to prevent regenerate thumbnails (if demo data archive is already contain cropped images)
            $options['regenerate_thumbnails'] = 3;
            // Default demo
            $options['files']['default']['title'] = esc_html__( 'Education Demo', 'dentalux' );
            $options['files']['default']['domain_dev'] = esc_url(ancora_get_protocol().'://dentalux.dv.ancorathemes.com'); // Developers domain
            $options['files']['default']['domain_demo']= esc_url(ancora_get_protocol().'://dentalux.ancorathemes.com'); // Demo-site domain

        }
        return $options;
    }
}

// Add theme required plugins
if ( !function_exists( 'ancora_add_trx_utils' ) ) {
    add_filter( 'trx_utils_active', 'ancora_add_trx_utils' );
    function ancora_add_trx_utils($enable=true) {
        return true;
    }
}



/* Include framework core files
------------------------------------------------------------------- */

require_once( get_template_directory().'/fw/loader.php' );
?>