<?php
/**
 * ANCORA Framework: messages subsystem
 *
 * @package	ancora
 * @since	ancora 1.0
 */

// Disable direct call
if ( ! defined( 'ABSPATH' ) ) { exit; }

// Theme init
if (!function_exists('ancora_messages_theme_setup')) {
	add_action( 'ancora_action_before_init_theme', 'ancora_messages_theme_setup' );
	function ancora_messages_theme_setup() {
		// Core messages strings
		add_action('ancora_action_add_scripts_inline', 'ancora_messages_add_scripts_inline');
	}
}


/* Session messages
------------------------------------------------------------------------------------- */

if (!function_exists('ancora_get_error_msg')) {
	function ancora_get_error_msg() {
		global $ANCORA_GLOBALS;
		return !empty($ANCORA_GLOBALS['error_msg']) ? $ANCORA_GLOBALS['error_msg'] : '';
	}
}

if (!function_exists('ancora_set_error_msg')) {
	function ancora_set_error_msg($msg) {
		global $ANCORA_GLOBALS;
		$msg2 = ancora_get_error_msg();
		$ANCORA_GLOBALS['error_msg'] = $msg2 . ($msg2=='' ? '' : '<br />') . ($msg);
	}
}

if (!function_exists('ancora_get_success_msg')) {
	function ancora_get_success_msg() {
		global $ANCORA_GLOBALS;
		return !empty($ANCORA_GLOBALS['success_msg']) ? $ANCORA_GLOBALS['success_msg'] : '';
	}
}

if (!function_exists('ancora_set_success_msg')) {
	function ancora_set_success_msg($msg) {
		global $ANCORA_GLOBALS;
		$msg2 = ancora_get_success_msg();
		$ANCORA_GLOBALS['success_msg'] = $msg2 . ($msg2=='' ? '' : '<br />') . ($msg);
	}
}

if (!function_exists('ancora_get_notice_msg')) {
	function ancora_get_notice_msg() {
		global $ANCORA_GLOBALS;
		return !empty($ANCORA_GLOBALS['notice_msg']) ? $ANCORA_GLOBALS['notice_msg'] : '';
	}
}

if (!function_exists('ancora_set_notice_msg')) {
	function ancora_set_notice_msg($msg) {
		global $ANCORA_GLOBALS;
		$msg2 = ancora_get_notice_msg();
		$ANCORA_GLOBALS['notice_msg'] = $msg2 . ($msg2=='' ? '' : '<br />') . ($msg);
	}
}


/* System messages (save when page reload)
------------------------------------------------------------------------------------- */
if (!function_exists('ancora_set_system_message')) {
	function ancora_set_system_message($msg, $status='info', $hdr='') {
		update_option('ancora_message', array('message' => $msg, 'status' => $status, 'header' => $hdr));
	}
}

if (!function_exists('ancora_get_system_message')) {
	function ancora_get_system_message($del=false) {
		$msg = get_option('ancora_message', false);
		if (!$msg)
			$msg = array('message' => '', 'status' => '', 'header' => '');
		else if ($del)
			ancora_del_system_message();
		return $msg;
	}
}

if (!function_exists('ancora_del_system_message')) {
	function ancora_del_system_message() {
		delete_option('ancora_message');
	}
}


/* Messages strings
------------------------------------------------------------------------------------- */

if (!function_exists('ancora_messages_add_scripts_inline')) {
	function ancora_messages_add_scripts_inline() {
		global $ANCORA_GLOBALS;
		echo '<script type="text/javascript">'
			. 'jQuery(document).ready(function() {'
			// Strings for translation
			. 'ANCORA_GLOBALS["strings"] = {'
				. 'bookmark_add: 		"' . addslashes(__('Add the bookmark', 'dentalux')) . '",'
				. 'bookmark_added:		"' . addslashes(__('Current page has been successfully added to the bookmarks. You can see it in the right panel on the tab \'Bookmarks\'', 'dentalux')) . '",'
				. 'bookmark_del: 		"' . addslashes(__('Delete this bookmark', 'dentalux')) . '",'
				. 'bookmark_title:		"' . addslashes(__('Enter bookmark title', 'dentalux')) . '",'
				. 'bookmark_exists:		"' . addslashes(__('Current page already exists in the bookmarks list', 'dentalux')) . '",'
				. 'search_error:		"' . addslashes(__('Error occurs in AJAX search! Please, type your query and press search icon for the traditional search way.', 'dentalux')) . '",'
				. 'email_confirm:		"' . addslashes(__('On the e-mail address <b>%s</b> we sent a confirmation email.<br>Please, open it and click on the link.', 'dentalux')) . '",'
				. 'reviews_vote:		"' . addslashes(__('Thanks for your vote! New average rating is:', 'dentalux')) . '",'
				. 'reviews_error:		"' . addslashes(__('Error saving your vote! Please, try again later.', 'dentalux')) . '",'
				. 'error_like:			"' . addslashes(__('Error saving your like! Please, try again later.', 'dentalux')) . '",'
				. 'error_global:		"' . addslashes(__('Global error text', 'dentalux')) . '",'
				. 'name_empty:			"' . addslashes(__('The name can\'t be empty', 'dentalux')) . '",'
				. 'name_long:			"' . addslashes(__('Too long name', 'dentalux')) . '",'
				. 'email_empty:			"' . addslashes(__('Too short (or empty) email address', 'dentalux')) . '",'
				. 'email_long:			"' . addslashes(__('Too long email address', 'dentalux')) . '",'
				. 'email_not_valid:		"' . addslashes(__('Invalid email address', 'dentalux')) . '",'
				. 'subject_empty:		"' . addslashes(__('The subject can\'t be empty', 'dentalux')) . '",'
				. 'subject_long:		"' . addslashes(__('Too long subject', 'dentalux')) . '",'
				. 'text_empty:			"' . addslashes(__('The message text can\'t be empty', 'dentalux')) . '",'
				. 'text_long:			"' . addslashes(__('Too long message text', 'dentalux')) . '",'
				. 'send_complete:		"' . addslashes(__("Send message complete!", 'dentalux')) . '",'
				. 'send_error:			"' . addslashes(__('Transmit failed!', 'dentalux')) . '",'
				. 'login_empty:			"' . addslashes(__('The Login field can\'t be empty', 'dentalux')) . '",'
				. 'login_long:			"' . addslashes(__('Too long login field', 'dentalux')) . '",'
				. 'login_success:		"' . addslashes(__('Login success! The page will be reloaded in 3 sec.', 'dentalux')) . '",'
				. 'login_failed:		"' . addslashes(__('Login failed!', 'dentalux')) . '",'
				. 'password_empty:		"' . addslashes(__('The password can\'t be empty and shorter then 4 characters', 'dentalux')) . '",'
				. 'password_long:		"' . addslashes(__('Too long password', 'dentalux')) . '",'
				. 'password_not_equal:	"' . addslashes(__('The passwords in both fields are not equal', 'dentalux')) . '",'
				. 'registration_success:"' . addslashes(__('Registration success! Please log in!', 'dentalux')) . '",'
				. 'registration_failed:	"' . addslashes(__('Registration failed!', 'dentalux')) . '",'
				. 'geocode_error:		"' . addslashes(__('Geocode was not successful for the following reason:', 'dentalux')) . '",'
				. 'googlemap_not_avail:	"' . addslashes(__('Google map API not available!', 'dentalux')) . '",'
				. 'editor_save_success:	"' . addslashes(__("Post content saved!", 'dentalux')) . '",'
				. 'editor_save_error:	"' . addslashes(__("Error saving post data!", 'dentalux')) . '",'
				. 'editor_delete_post:	"' . addslashes(__("You really want to delete the current post?", 'dentalux')) . '",'
				. 'editor_delete_post_header:"' . addslashes(__("Delete post", 'dentalux')) . '",'
				. 'editor_delete_success:	"' . addslashes(__("Post deleted!", 'dentalux')) . '",'
				. 'editor_delete_error:		"' . addslashes(__("Error deleting post!", 'dentalux')) . '",'
				. 'editor_caption_cancel:	"' . addslashes(__('Cancel', 'dentalux')) . '",'
				. 'editor_caption_close:	"' . addslashes(__('Close', 'dentalux')) . '"'
				. '};'
			. '});'
			. '</script>';
	}
}
?>